@@ -1,4 +1,5 @@
 import torch
+import math
 
 # Spike-gradient functions
 
@@ -147,6 +148,62 @@ def fast_sigmoid(slope=25):
     return inner
 
 
+class ATan(torch.autograd.Function):
+    """
+    Surrogate gradient of the Heaviside step function.
+
+    **Forward pass:** Heaviside step function shifted.
+
+        .. math::
+
+            S=\\begin{cases} 1 & \\text{if U ≥ U$_{\\rm thr}$} \\\\
+            0 & \\text{if U < U$_{\\rm thr}$}
+            \\end{cases}
+
+    **Backward pass:** Gradient of shifted arc-tan function.
+
+        .. math::
+
+                S&≈\\frac{1}{π}\\text{arctan}(πU \\frac{α}{2}) \\\\
+                \\frac{∂S}{∂U}&=\\frac{1}{π}\\frac{1}{(1+(πU\\frac{α}{2})^2}
+
+
+    :math:`alpha` defaults to 2, and can be modified by calling ``surrogate.atan(alpha=2)``.
+
+    Adapted from:
+
+    *W. Fang, Z. Yu, Y. Chen, T. Masquelier, T. Huang, Y. Tian (2021) Incorporating Learnable Membrane Time Constants to Enhance Learning of Spiking Neural Networks. Proc. IEEE/CVF Int. Conf. Computer Vision (ICCV), pp. 2661-2671.*"""
+
+    @staticmethod
+    def forward(ctx, input_, alpha=2.0):
+        ctx.save_for_backward(input_)
+        ctx.alpha = alpha
+        out = (input_ > 0).float()
+        return out
+
+    @staticmethod
+    def backward(ctx, grad_output):
+        (input_,) = ctx.saved_tensors
+        grad_input = grad_output.clone()
+        grad = (
+            ctx.alpha
+            / 2
+            / (1 + (math.pi / 2 * ctx.alpha * input_).pow_(2))
+            * grad_input
+        )
+        return grad, None
+
+
+def atan(alpha=2.0):
+    """ArcTan surrogate gradient enclosed with a parameterized slope."""
+    alpha = alpha
+
+    def inner(x):
+        return ATan.apply(x, alpha)
+
+    return inner
+
+
 class Sigmoid(torch.autograd.Function):
     """
     Surrogate gradient of the Heaviside step function.
