@@ -135,17 +135,23 @@ def reset(net):
     Reset their hidden parameters to zero and detach them
     from the current computation graph."""
 
-    global is_stein
     global is_alpha
     global is_leaky
     global is_lapicque
+    global is_rleaky
     global is_synaptic
+    global is_rsynaptic
+    global is_sconv2dlstm
+    global is_slstm
 
-    is_stein = False
     is_alpha = False
     is_leaky = False
+    is_rleaky = False
     is_synaptic = False
+    is_rsynaptic = False
     is_lapicque = False
+    is_sconv2dlstm = False
+    is_slstm = False
 
     _layer_check(net=net)
 
@@ -158,8 +164,11 @@ def _layer_check(net):
     global is_leaky
     global is_lapicque
     global is_synaptic
-    global is_stein
     global is_alpha
+    global is_rleaky
+    global is_rsynaptic
+    global is_sconv2dlstm
+    global is_slstm
 
     for idx in range(len(list(net._modules.values()))):
         if isinstance(list(net._modules.values())[idx], snn.Lapicque):
@@ -168,10 +177,16 @@ def _layer_check(net):
             is_synaptic = True
         if isinstance(list(net._modules.values())[idx], snn.Leaky):
             is_leaky = True
-        if isinstance(list(net._modules.values())[idx], snn.Stein):
-            is_stein = True
         if isinstance(list(net._modules.values())[idx], snn.Alpha):
             is_alpha = True
+        if isinstance(list(net._modules.values())[idx], snn.RLeaky):
+            is_rleaky = True
+        if isinstance(list(net._modules.values())[idx], snn.RSynaptic):
+            is_rsynaptic = True
+        if isinstance(list(net._modules.values())[idx], snn.SConv2dLSTM):
+            is_sconv2dlstm = True
+        if isinstance(list(net._modules.values())[idx], snn.SLSTM):
+            is_slstm = True
 
 
 def _layer_reset():
@@ -186,12 +201,21 @@ def _layer_reset():
     if is_leaky:
         snn.Leaky.reset_hidden()  # reset hidden state to 0's
         snn.Leaky.detach_hidden()
-    if is_stein:
-        snn.Stein.reset_hidden()  # reset hidden state to 0's
-        snn.Stein.detach_hidden()
     if is_alpha:
         snn.Alpha.reset_hidden()  # reset hidden state to 0's
         snn.Alpha.detach_hidden()
+    if is_rleaky:
+        snn.RLeaky.reset_hidden()  # reset hidden state to 0's
+        snn.RLeaky.detach_hidden()
+    if is_rsynaptic:
+        snn.RSynaptic.reset_hidden()  # reset hidden state to 0's
+        snn.RSynaptic.detach_hidden()
+    if is_sconv2dlstm:
+        snn.SConv2dLSTM.reset_hidden()  # reset hidden state to 0's
+        snn.SConv2dLSTM.detach_hidden()
+    if is_slstm:
+        snn.SLSTM.reset_hidden()  # reset hidden state to 0's
+        snn.SLSTM.detach_hidden()
 
 
 def _final_layer_check(net):
@@ -201,9 +225,15 @@ def _final_layer_check(net):
         return 2
     if isinstance(list(net._modules.values())[-1], snn.Synaptic):
         return 3
+    if isinstance(list(net._modules.values())[-1], snn.RSynaptic):
+        return 3
     if isinstance(list(net._modules.values())[-1], snn.Leaky):
         return 2
-    if isinstance(list(net._modules.values())[-1], snn.Stein):
+    if isinstance(list(net._modules.values())[-1], snn.RLeaky):
+        return 2
+    if isinstance(list(net._modules.values())[-1], snn.SConv2dLSTM):
+        return 3
+    if isinstance(list(net._modules.values())[-1], snn.SLSTM):
         return 3
     if isinstance(list(net._modules.values())[-1], snn.Alpha):
         return 4
